X-Git-Url: https://git.p6c8.net/jirafeau_project.git/blobdiff_plain/0b85af176ceecbd94fad0b48977abf6eeff9c0c0..93d7dffa6e851ee8e2c1c0708c78caff3fa35dd7:/index.php
diff --git a/index.php b/index.php
index 8e512b6..24565bd 100644
--- a/index.php
+++ b/index.php
@@ -2,7 +2,7 @@
/*
* Jirafeau, your web file repository
* Copyright (C) 2013
- * Jerome Jutteau
+ * Jerome Jutteau
* Jimmy Beauvois
*
* This program is free software: you can redistribute it and/or modify
@@ -25,45 +25,48 @@ require(JIRAFEAU_ROOT . 'lib/settings.php');
require(JIRAFEAU_ROOT . 'lib/functions.php');
require(JIRAFEAU_ROOT . 'lib/lang.php');
+if ($cfg['download_password_requirement'] === "generated"){
+ $download_pass = jirafeau_gen_download_pass($cfg['download_password_gen_len'], $cfg['download_password_gen_chars']);
+}
+
check_errors($cfg);
if (has_error()) {
+ require(JIRAFEAU_ROOT . 'lib/template/header.php');
show_errors();
require(JIRAFEAU_ROOT . 'lib/template/footer.php');
exit;
}
-
require(JIRAFEAU_ROOT . 'lib/template/header.php');
+// Logout action
+if (isset($_POST['action']) && (strcmp($_POST['action'], 'logout') == 0)) {
+ jirafeau_session_end();
+}
+
/* Check if user is allowed to upload. */
-// First check: Challenge by IP NO PASSWORD
-if (true === jirafeau_challenge_upload_ip($cfg['upload_ip_nopassword'], get_ip_address($cfg))) {
- $_SESSION['upload_auth'] = true;
- $_POST['upload_password'] = '';
- $_SESSION['user_upload_password'] = $_POST['upload_password'];
+// First check: Is user already logged
+if (jirafeau_user_session_logged()) {
+}
+// Second check: Challenge by IP NO PASSWORD
+elseif (true === jirafeau_challenge_upload_ip_without_password($cfg, get_ip_address($cfg))) {
+ jirafeau_user_session_start();
}
-// Second check: Challenge by IP
-elseif (true === jirafeau_challenge_upload_ip($cfg['upload_ip'], get_ip_address($cfg))) {
+// Third check: Challenge by IP
+elseif (true === jirafeau_challenge_upload_ip($cfg, get_ip_address($cfg))) {
// Is an upload password required?
if (jirafeau_has_upload_password($cfg)) {
- // Logout action
- if (isset($_POST['action']) && (strcmp($_POST['action'], 'logout') == 0)) {
- session_unset();
- }
-
// Challenge by password
- // â¦save successful logins in session
if (isset($_POST['upload_password'])) {
if (jirafeau_challenge_upload_password($cfg, $_POST['upload_password'])) {
- $_SESSION['upload_auth'] = true;
- $_SESSION['user_upload_password'] = $_POST['upload_password'];
+ jirafeau_user_session_start();
} else {
- $_SESSION['admin_auth'] = false;
+ jirafeau_session_end();
jirafeau_fatal_error(t('BAD_PSW'), $cfg);
}
}
// Show login form if user session is not authorized yet
- if (true === empty($_SESSION['upload_auth'])) {
+ if (!jirafeau_user_session_logged()) {
?>
-
+
+
+
+
@@ -122,7 +138,7 @@ else {
+ } ?>
@@ -161,124 +177,128 @@ else {
+?>
@@ -291,13 +311,17 @@ else {
document.getElementById('send').style.display = 'none';
if (!check_html5_file_api ())
document.getElementById('max_file_size').innerHTML = '';
+ $max_size = jirafeau_get_max_upload_size();
+if ($max_size > 0) {
+ echo t('NO_BROWSER_SUPPORT') . $max_size;
+}
+?>';
addCopyListener('upload_link_button', 'upload_link');
addCopyListener('preview_link_button', 'preview_link');
addCopyListener('direct_link_button', 'direct_link');
addCopyListener('delete_link_button', 'delete_link');
+ addTextCopyListener('password_copy_button', 'output_key');
// @license-end